=======
Credits
=======

Development Lead
----------------

* Dario Quintero <darioaquintero@gmail.com>

Appreciated Conversations
------------------------------------

* Jeremy Adcock - University of Bristol
* Josh Silverstone - University of Bristol
* Sebastian Currie - University of Bristol
* Quinn Palmer - University of Bristol
* Joaquin Matres - Google X
* Jan David Fischbach - RWTH Aachen University

Contributors
------------

None yet. Why not be the first?
